@@ -1,11 +1,12 @@
 package Fey::DBIManager;
+BEGIN {
+  $Fey::DBIManager::VERSION = '0.12';
+}
 
 use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.11';
-
 use Fey::Exceptions qw( object_state_error param_error );
 use Scalar::Util qw( blessed );
 
@@ -89,12 +90,20 @@ __PACKAGE__->meta()->make_immutable();
 
 1;
 
-__END__
+# ABSTRACT: Manage a set of DBI handles
+
+
+
+=pod
 
 =head1 NAME
 
 Fey::DBIManager - Manage a set of DBI handles
 
+=head1 VERSION
+
+version 0.12
+
 =head1 SYNOPSIS
 
   my $manager = Fey::DBIManager->new();
@@ -165,10 +174,6 @@ By default, this method simply returns the default source. It exists
 to provide a spot for subclasses which want to do something more
 clever, such as use one source for reads and another for writes.
 
-=head1 AUTHOR
-
-Dave Rolsky, <autarch@urth.org>
-
 =head1 BUGS
 
 Please report any bugs or feature requests to
@@ -176,11 +181,20 @@ C<bug-fey-dbimanager@rt.cpan.org>, or through the web interface at
 L<http://rt.cpan.org>.  I will be notified, and then you'll
 automatically be notified of progress on your bug as I make changes.
 
-=head1 COPYRIGHT & LICENSE
+=head1 AUTHOR
 
-Copyright 2006-2008 Dave Rolsky, All Rights Reserved.
+  Dave Rolsky <autarch@urth.org>
 
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2010 by Dave Rolsky.
+
+This is free software, licensed under:
+
+  The Artistic License 2.0
 
 =cut
+
+
+__END__
+
